==> james-project-3.6.2-source-release.zip: james-project/server/protocols/jmap-draft/src/main/java/org/apache/james/jmap/draft/exceptions/AttachmentsNotFoundException.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.draft.exceptions;

import java.util.List;

import org.apache.james.jmap.draft.model.BlobId;

import com.google.common.collect.ImmutableList;

public class AttachmentsNotFoundException extends Exception {
    
    private List<BlobId> attachmentIds;


    public AttachmentsNotFoundException(List<BlobId> attachmentIds) {
        this.attachmentIds = ImmutableList.copyOf(attachmentIds);
    }
    
    public List<BlobId> getAttachmentIds() {
        return attachmentIds;
    }
}

==> james-project-3.7.6-source-release.zip: james-project/server/protocols/jmap-draft/src/main/java/org/apache/james/jmap/draft/exceptions/AttachmentsNotFoundException.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.draft.exceptions;

import java.util.List;

import org.apache.james.jmap.draft.model.BlobId;

import com.google.common.collect.ImmutableList;

public class AttachmentsNotFoundException extends RuntimeException {
    
    private List<BlobId> attachmentIds;


    public AttachmentsNotFoundException(List<BlobId> attachmentIds) {
        this.attachmentIds = ImmutableList.copyOf(attachmentIds);
    }
    
    public List<BlobId> getAttachmentIds() {
        return attachmentIds;
    }
}
